###########################################################################
#
# Measurement Uncertainty Calculator - Copyright (C) 2019
# Leverhulme Research Centre for Forensic Science
# Roy Mudie, Joyce Klu, Niamh Nic Daeid
# Website: https://github.com/LRCFS/lrcfs-measurement-uncertainty-calculator/
# Contact: lrc@dundee.ac.uk
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
###########################################################################

tabSampleVolume = tabItem(tabName = "sampleVolume",
                 fluidRow(
                   valueBox("Uncertainty of Sample Volume", h2(uiOutput("display_sampleVolume_finalAnswer_top")), width = 12, color = "maroon", icon = icon("vial"))
                 ),
                 fluidRow(
                   box(title = "Overview", width=5,
                       p("The uncertainty of sample volume quantifies the uncertainty associated with quantifying the volume of case sample through the use of for example pipette.")
                   ),
                   box(title = "Method", width=7,
                       "The RSU of each equipment is computed using:",
                       "$$u_r(\\text{Equipment}) = \\frac{\\frac{\\text{Tolerance}}{\\text{Coverage Factor}}}{\\text{Volume}}$$",
                       "The RSU of sample volume is given by:",
                       "$$u_r\\text{(SampleVolume)} = \\sqrt{\\sum{[u_r(\\text{Equipment})_{\\text{(Vol,Tol)}}^2 \\times N(\\text{Equipment})_{\\text{(Vol,Tol)}}}]}$$",
                       tags$ul(
                         tags$li("\\(N\\text{(Equipment)}\\) is the number of times a piece of equipment is used in taking the volume of a given sample.")
                       )
                   )
                 ),
                 fluidRow(
                   tabBox(width=12, side="right",
                          title = "Loaded Data",
                          tabPanel("Raw Sample Volume Data",
                                   DT::dataTableOutput("display_sampleVolume_rawDataTable")
                          )
                   )
                 ),
                 fluidRow(
                   box(width=6, side="right",
                       title = "Standard Uncertainty",
                       uiOutput("display_sampleVolume_standardUncertainty")
                   ),
                   box(width=6, side="right",
                       title = "Relative Standard Uncertainty",
                       uiOutput("display_sampleVolume_relativeStandardUncertainty")
                   )
                 ),
                 fluidRow(
                   box(width=12, side="right",
                       title = "Overall Relative Standard Uncertainty", background = "maroon", solidHeader = TRUE,
                       uiOutput("display_sampleVolume_finalAnswer_bottom")
                   )
                 )
)
